@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bdatajob.cpp 475317 2005-10-28 21:06:04Z trueg $
+ * $Id: k3bdatajob.cpp 507450 2006-02-09 09:01:24Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -311,8 +311,19 @@ void K3bDataJob::slotIsoImagerFinished( bool success )
       cancelAll();
     }
   }
+  else if( !success ) {
+    //
+    // In case the imager failed let's make sure the writer does not emit an unusable
+    // error message.
+    //
+    if( m_writerJob->active() )
+      m_writerJob->setSourceUnreadable( true );
 
-  // in case we are writing on the fly we leave the error handling to slotWriterJobFinished
+    // there is one special case which we need to handle here: the iso imager might be cancelled 
+    // FIXME: the iso imager should not be able to cancel itself
+    if( m_isoImager->hasBeenCanceled() && !this->hasBeenCanceled() )
+      cancel();
+  }
 }
 
 
@@ -457,7 +468,7 @@ void K3bDataJob::slotVerificationFinished( bool success )
 
   d->copiesDone++;
 
-  if( !k3bcore->globalSettings()->ejectMedia() || d->copiesDone < d->copies )
+  if( k3bcore->globalSettings()->ejectMedia() || d->copiesDone < d->copies )
     K3bDevice::eject( d->doc->burner() );
   
   if( d->copiesDone < d->copies ) {
@@ -470,8 +481,21 @@ void K3bDataJob::slotVerificationFinished( bool success )
     if( failed )
       cancelAll();
   }
-  else
+  else {
+    if( !d->doc->onTheFly() && d->doc->removeImages() ) {
+      if( QFile::exists( d->doc->tempDir() ) ) {
+	QFile::remove( d->doc->tempDir() );
+	emit infoMessage( i18n("Removed image file %1").arg(d->doc->tempDir()), K3bJob::SUCCESS );
+      }
+    }
+    
+    if( d->tocFile ) {
+      delete d->tocFile;
+      d->tocFile = 0;
+    }
+
     emit finished( success );
+  }
 }
 
 
