@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bisoimager.cpp 476670 2005-11-01 19:12:27Z trueg $
+ * $Id: k3bisoimager.cpp 487838 2005-12-12 08:53:11Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -232,11 +232,11 @@ void K3bIsoImager::calculateSize()
 
   initMkisofs( d->mkisofsBin );
 
-  emit debuggingOutput( "Used versions", "mkisofs: " + d->mkisofsBin->version );
+//   emit debuggingOutput( "Used versions", "mkisofs: " + d->mkisofsBin->version );
 
-  if( !d->mkisofsBin->copyright.isEmpty() )
-    emit infoMessage( i18n("Using %1 %2 - Copyright (C) %3")
-		      .arg("mkisofs").arg(d->mkisofsBin->version).arg(d->mkisofsBin->copyright), INFO );
+//   if( !d->mkisofsBin->copyright.isEmpty() )
+//     emit infoMessage( i18n("Using %1 %2 - Copyright (C) %3")
+// 		      .arg("mkisofs").arg(d->mkisofsBin->version).arg(d->mkisofsBin->copyright), INFO );
 
   *m_process << d->mkisofsBin;
 
@@ -281,6 +281,10 @@ void K3bIsoImager::calculateSize()
   connect( m_process, SIGNAL(processExited(KProcess*)),
 	   this, SLOT(slotMkisofsPrintSizeFinished()) );
 
+  // we also want error messages
+  connect( m_process, SIGNAL(stderrLine( const QString& )),
+	   this, SLOT(slotReceivedStderr( const QString& )) );
+
   m_collectedMkisofsPrintSizeStdout = QString::null;
   m_collectedMkisofsPrintSizeStderr = QString::null;
   m_mkisofsPrintSizeResult = 0;
@@ -891,12 +895,58 @@ bool K3bIsoImager::writeSortWeightFile()
 
 QString K3bIsoImager::escapeGraftPoint( const QString& str )
 {
-  QString newStr( str );
+  QString enc = str;
 
-  newStr.replace( "\\\\", "\\\\\\\\" );
-  newStr.replace( "=", "\\=" );
+  //
+  // mkisofs manpage (-graft-points) is incorrect (as of mkisofs 2.01.01)
+  //
+  // Actually an equal sign needs to be escaped with one backslash only
+  // Single backslashes inside a filename can be used without change
+  // while single backslashes at the end of a filename need to be escaped
+  // with two backslashes.
+  //
+  // There is one more problem though: the name in the iso tree can never 
+  // in any number of backslashes. mkisofs simply cannot handle it. So we
+  // need to remove these slashes somewhere or ignore those files (we do 
+  // that in K3bDataDoc::addUrls)
+  //
 
-  return newStr;
+  //
+  // we do not use QString::replace to have full control
+  // this might be slow since QString::insert is slow but we don't care
+  // since this is only called to prepare the iso creation which is not 
+  // time critical. :)
+  //
+
+  int pos = 0;
+  while( pos < enc.length() ) {
+    // escape every equal sign with one backslash
+    if( enc[pos] == '=' ) {
+      enc.insert( pos, "\\" );
+      pos += 2;
+    }
+    else if( enc[pos] == '\\' ) {
+      // escape every occurence of two backslashes with two backslashes
+      if( pos+1 < enc.length() && enc[pos+1] == '\\' ) {
+	enc.insert( pos, "\\\\" );
+	pos += 4;
+      }
+      // escape the last single backslash in the filename (see above)
+      else if( pos == enc.length()-1 ) {
+	enc.insert( pos, "\\" );
+	pos += 2;
+      }
+      else
+	++pos;
+    }
+    else
+      ++pos;
+  }
+
+//   enc.replace( "\\\\", "\\\\\\\\" );
+//   enc.replace( "=", "\\=" );
+
+  return enc;
 }
 
 
@@ -962,10 +1012,10 @@ QString K3bIsoImager::dummyDir( K3bDirItem* dir )
   name += QString::number( dir->sortWeight() );
 
   bool perm = false;
-  struct stat statBuf;
+  struct stat64 statBuf;
   if( !dir->localPath().isEmpty() ) {
     // permissions
-    if( ::stat( QFile::encodeName( dir->localPath() ), &statBuf ) == 0 ) {
+    if( ::stat64( QFile::encodeName( dir->localPath() ), &statBuf ) == 0 ) {
       name += "_";
       name += QString::number( statBuf.st_uid );
       name += "_";
