@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bdvdjob.cpp 475316 2005-10-28 21:04:12Z trueg $
+ * $Id: k3bdvdjob.cpp 501294 2006-01-22 15:18:18Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -182,6 +182,8 @@ void K3bDvdJob::prepareGrowisofsImager()
     connect( m_growisofsImager, SIGNAL(debuggingOutput(const QString&, const QString&)), 
 	     this, SIGNAL(debuggingOutput(const QString&, const QString&)) );
   }
+
+  m_growisofsImager->setUsedMultiSessionMode( d->usedMultiSessionMode );
 }
 
 
@@ -546,7 +548,7 @@ void K3bDvdJob::slotDetermineMultiSessionMode( K3bDevice::DeviceHandler* dh )
 
     // try to check the filesystem size
     K3bIso9660 iso( m_doc->burner() );
-    if( iso.open() && info.capacity() - iso.primaryDescriptor().volumeSpaceSize >= m_doc->length() ) {
+    if( iso.open() && info.capacity() - iso.primaryDescriptor().volumeSpaceSize >= ( m_doc->burningSize() / 2048 ) ) {
       d->usedMultiSessionMode = K3bDataDoc::CONTINUE;
     }
     else {
@@ -560,7 +562,7 @@ void K3bDvdJob::slotDetermineMultiSessionMode( K3bDevice::DeviceHandler* dh )
     //  2. the project does fit and fills up the CD -> finish multisession
     //  3. the project does fit and does not fill up the CD -> continue multisession
     //
-    if( m_doc->size() > info.remainingSize().mode1Bytes() )
+    if( m_doc->size() > info.remainingSize().mode1Bytes() && m_doc->size() == m_doc->burningSize() )
       d->usedMultiSessionMode = K3bDataDoc::NONE;
     else if( m_doc->size() >= info.remainingSize().mode1Bytes()*9/10 )
       d->usedMultiSessionMode = K3bDataDoc::FINISH;
@@ -568,7 +570,14 @@ void K3bDvdJob::slotDetermineMultiSessionMode( K3bDevice::DeviceHandler* dh )
       d->usedMultiSessionMode = K3bDataDoc::CONTINUE;
   }
   else {
-    d->usedMultiSessionMode = K3bDataDoc::NONE;
+    //
+    // We only close the DVD if the project fills it up almost completely (90%)
+    //
+    if( m_doc->size() >= info.capacity().mode1Bytes()*9/10 ||
+	m_doc->writingMode() == K3b::DAO )
+      d->usedMultiSessionMode = K3bDataDoc::NONE;
+    else
+      d->usedMultiSessionMode = K3bDataDoc::START;
   }
 
   if( d->usedMultiSessionMode != K3bDataDoc::NONE ) {
@@ -691,9 +700,9 @@ bool K3bDvdJob::waitForDvd()
 
 	// FIXME: DVD-R DL jump and stuff
 
-	if( m_doc->writingMode() == K3b::DAO ||
-	    ( m_doc->writingMode() == K3b::WRITING_MODE_AUTO &&
-	      d->usedMultiSessionMode == K3bDataDoc::NONE ) )
+	if( m_doc->writingMode() == K3b::DAO )
+//	    ( m_doc->writingMode() == K3b::WRITING_MODE_AUTO &&
+//	      d->usedMultiSessionMode == K3bDataDoc::NONE ) )
 	  emit infoMessage( i18n("Writing %1 in DAO mode.").arg( K3bDevice::mediaTypeString(d->foundMedia, true) ), INFO );
 
 	else {
