@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bmixedjob.cpp 397363 2005-03-13 20:27:13Z trueg $
+ * $Id: k3bmixedjob.cpp 509861 2006-02-15 18:35:29Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -707,8 +707,8 @@ bool K3bMixedJob::writeTocFile()
     m_tocFile->close();
 
     // backup for debugging
-    KIO::NetAccess::del("/tmp/trueg/tocfile_debug_backup.toc",0L);
-    KIO::NetAccess::copy( m_tocFile->name(), "/tmp/trueg/tocfile_debug_backup.toc",0L );
+//    KIO::NetAccess::del("/tmp/trueg/tocfile_debug_backup.toc",0L);
+//    KIO::NetAccess::copy( m_tocFile->name(), "/tmp/trueg/tocfile_debug_backup.toc",0L );
 
     return success;
   }
