@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bdevicemanager.cpp 424796 2005-06-13 07:56:48Z trueg $
+ * $Id: k3bdevicemanager.cpp 501293 2006-01-22 15:16:37Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -651,8 +651,8 @@ bool K3bDevice::DeviceManager::testForCdrom(const QString& devicename)
     if( cmd.transport( TR_DIR_READ, buf, sizeof(buf) ) ) {
       kdError() << "(K3bDevice::Device) Unable to do inquiry." << endl;
     }
-    else if( (inq->p_device_type&0x1f) != 0x5 ) {
-      kdDebug() << devicename << " seems not to be a cdrom device: " << strerror(errno) << endl;
+    else if( inq->p_device_type != 0x5 ) {
+      kdDebug() << devicename << " seems not to be a cdrom device: " << (int)inq->p_device_type << endl;
     }
     else {
       ret = true;
