@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bcdimagewritingdialog.cpp 471081 2005-10-16 10:55:47Z trueg $
+ * $Id: k3bcdimagewritingdialog.cpp 487843 2005-12-12 09:30:25Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -171,6 +171,7 @@ void K3bCdImageWritingDialog::setupGui()
   // -----------------------------------------------------------------------
   QGroupBox* groupImageUrl = new QGroupBox( 1, Qt::Horizontal, i18n("Image to Burn"), frame );
   m_editImagePath = new KURLRequester( groupImageUrl );
+  m_editImagePath->setMode( KFile::File|KFile::ExistingOnly );
   m_editImagePath->setCaption( i18n("Choose Image File") );
   m_editImagePath->setFilter( i18n("*.iso *.toc *.ISO *.TOC *.cue *.CUE|Image Files") 
 			      + "\n"
@@ -969,7 +970,7 @@ int K3bCdImageWritingDialog::currentImageType()
 
 QString K3bCdImageWritingDialog::imagePath() const
 {
-  return KURL::fromPathOrURL( m_editImagePath->url() ).path();
+  return K3b::convertToLocalUrl( KURL::fromPathOrURL( m_editImagePath->url() ) ).path();
 }
 
 
